#! /bin/sh
#
#      Diogene87
#      Copyright (C) 2003,2004,2005,2006,2007 - Dominique Parisot
#
if [ "x$buildpath" = "x" ] ; then
	buildpath=`pwd`
fi
if [ "`uname`" = "Linux" ] ; then
	echo "Setting ulimit"
	ulimit -c unlimited
	ulimit -n 10
fi

dio87d_dir="$buildpath/../src/dio87d"
dio87c_dir="$buildpath/../src/dio87c"
dio87d_cmd="$dio87d_dir/dio87d"
dio87c_cmd="$dio87c_dir/dio87c"
PATH="$dio87d_dir:$dio87c_dir:$PATH"
export PATH
export DG87_USER="admin"
export DG87_PASSWORD=""
JOBPATH="$buildpath/$srcdir/jobs"
DATAPATH="$buildpath/data"
dayDate=`date +"%Y-%m-%d %H:%M:%S"`
# check data directory
if [ ! -d "$DATAPATH"  ]; then
# create directory
mkdir "$DATAPATH" || exit 1 
else
# remove previous data files
rm "$DATAPATH"/* -f >/dev/null 2>&1 
fi
# create 'dio87d' configuration file
cat > $DATAPATH/dio87d.conf << EOF
IPPORT=9993
PID_FILE=$DATAPATH/dio87d.pid
DATA_DIR=$DATAPATH
SAVE_TEMPO=300
LOG_LEVEL=NONE
EOF

# create 'dio87c' configuration file
cat > $DATAPATH/dio87c.conf << EOF
DG87_ADDRESS=localhost
DG87_IPPORT=9993
EOF
ps -e | grep [d]io87d > /dev/null 
if [ $? -eq 0 ]; then

echo "dio87d is already running";exit 1 
fi

echo "__________________________________________________________________"

echo "|"

echo "| tst02 (Test target and queue commands)"

echo "|"

printf " Start dio87d ...................................................."

# initialize previous database
rm DATAPATH/dio87d.data >/dev/null 2>&1
"$dio87d_cmd" -C "$DATAPATH/dio87d.conf" -I >/dev/null 2>&1
"$dio87d_cmd" -C "$DATAPATH/dio87d.conf" -d $DAEMON_OPTION
sleep 1
dio87c -- version >/dev/null 2>&1
if [  $? -ne 0 ]; then
echo ""
echo "Can't communicate with dio87d";exit 1 
fi


echo " done"

printf " Check target commands ..........................................."

mema1=`dio87c -- memory`
if [ $? -ne 0 ]; then
if [ "$mema1" = "Unknown command 'memory'" ]; then
mema1=0
else
echo ""
echo "Error of the memory command";exit 1  
fi

fi


dio87c -- ta tg1 
if [  $? -ne 0 ]; then
echo ""
echo "Can't create a new target!";exit 1 
fi


dio87c -- ta tg2 
if [  $? -ne 0 ]; then
echo ""
echo "Can't create a new target!";exit 1 
fi


res=`dio87c -- tc`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get target count!";exit 1 
fi

if [ $res -ne 3 ]; then
echo ""
echo "Target count is not 3!";exit 1 
fi

dio87c -- tl | grep "^localhost$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the localhost target!";exit 1 
fi

dio87c -- tl | grep "^tg1$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the target tg1!";exit 1 
fi

dio87c -- tl | grep "^tg2$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the target tg2!";exit 1 
fi


dio87c -- ta tg1 > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can add a second target with the same name!";exit 1 
fi

res=`dio87c -- tc`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get target count!";exit 1 
fi

if [ $res -ne 3 ]; then
echo ""
echo "Target count is not 3!";exit 1 
fi


dio87c -- tsn tg1 new_tg1 
if [  $? -ne 0 ]; then
echo ""
echo "Can't rename the target!";exit 1 
fi


dio87c -- tl | grep "^new_tg1$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the renamed target!";exit 1 
fi

dio87c -- tsn new_tg1 tg1 
if [  $? -ne 0 ]; then
echo ""
echo "Can't rename the target!";exit 1 
fi


dio87c -- tsn tg1 tg2 > /dev/null 
if [ $? -eq 0 ]; then
Can rename a target with a name which already exists!
fi

dio87c -- tl | grep "^tg1$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the target tg1!";exit 1 
fi

dio87c -- tl | grep "^tg2$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the target tg2!";exit 1 
fi


dio87c -- tsd tg1 new_description 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change the target description!";exit 1 
fi


dio87c -- ti -S_ tg1 | grep "^Description_new_description$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Target description is not set!";exit 1 
fi

dio87c -- tsd tg1 "" 
if [  $? -ne 0 ]; then
echo ""
echo "Can't erase the target description!";exit 1 
fi


dio87c -- ti -S_ tg1 | grep "^Description_$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Target description is not set!";exit 1 
fi


dio87c -- tso tg1 false 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change the 'opened' property!";exit 1 
fi


dio87c -- ti -S_ tg1 | grep "^Opened_false$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "The 'opened' property is not set!";exit 1 
fi

dio87c -- tso tg1 true 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change the 'opened' property!";exit 1 
fi


dio87c -- ti -S_ tg1 | grep "^Opened_true$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "The 'opened' property is not set!";exit 1 
fi


dio87c -- tsp tg1 8888 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change the IP Port property!";exit 1 
fi


dio87c -- ti -S_ tg1 | grep "^IP Port_8888$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "The 'IP port' property is not set!";exit 1 
fi


dio87c -- tk tg1 
if [  $? -ne 0 ]; then
echo ""
echo "Can't delete a target!";exit 1 
fi


dio87c -- tk tg2 
if [  $? -ne 0 ]; then
echo ""
echo "Can't delete a target!";exit 1 
fi


res=`dio87c -- tc`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get target count!";exit 1 
fi

if [ $res -ne 1 ]; then
echo ""
echo "Target count is not 1!";exit 1 
fi


dio87c -- tk xxx > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can kill a target which does not exist!";exit 1 
fi

dio87c -- tk localhost > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can kill a 'localhost' target!";exit 1 
fi

res=`dio87c -- tc`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get target count!";exit 1 
fi

if [ $res -ne 1 ]; then
echo ""
echo "Target count is not 1!";exit 1 
fi

dio87c -- tl | grep "^localhost$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the localhost target!";exit 1 
fi


dio87c -- ta "abAZ09-" 
if [  $? -ne 0 ]; then
echo ""
echo "Can't create a target with valid character!";exit 1 
fi


dio87c -- tl | grep "^abAZ09-$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the target!";exit 1 
fi

dio87c -- tk "abAZ09-" || exit 1 
dio87c -- ta "target@" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can add a target with invalid character!";exit 1 
fi

dio87c -- tl | grep "^target@$" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "The target was created!";exit 1 
fi

dio87c -- ta "" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can add a target with an empty name!";exit 1 
fi


dio87c -- ta tg1 || exit 1 
dio87c -- tsn tg1 "abAZ09-" 
if [  $? -ne 0 ]; then
echo ""
echo "Can't rename a target with valid character!";exit 1 
fi


dio87c -- tl | grep "^abAZ09-$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the target!";exit 1 
fi

dio87c -- tsn "abAZ09-" tg1 || exit 1 
dio87c -- tsn tg1 "target@" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can rename a target with invalid character!";exit 1 
fi

dio87c -- tl | grep "^target@$" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "The target was created!";exit 1 
fi

dio87c -- tk tg1 || exit 1 

dio87c -- tl | grep "^localhost$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the localhost target!";exit 1 
fi

res=`dio87c -- tc`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get target count!";exit 1 
fi

if [ $res -ne 1 ]; then
echo ""
echo "Target count is not 1!";exit 1 
fi

dio87c -- tk localhost > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can kill the localhost target!";exit 1 
fi

dio87c -- tl | grep "^localhost$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "The localhost target has been deleted!";exit 1 
fi

dio87c -- tsn localhost new_name > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can rename the localhost target!";exit 1 
fi

dio87c -- tl | grep "^localhost$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "The localhost target has been renamed!";exit 1 
fi

dio87c -- tsp localhost 8888 > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can change the localhost IP port!";exit 1 
fi

dio87c -- ti -S_ localhost | grep "^IP Port_8888$" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "The IP port of localhost has been changed!";exit 1 
fi

dio87c -- tsh localhost new_hostname > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can change the hostname of localhost!";exit 1 
fi

dio87c -- ti -S_ localhost | grep "^Host Name_$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "The hostname of localhost has been changed!";exit 1 
fi



memb1=`dio87c -- memory`
if [ $? -ne 0 ]; then
if [ "$memb1" = "Unknown command 'memory'" ]; then
memb1=0
else
echo ""
echo "Error of the memory command";exit 1  
fi

fi
if [  $mema1 -ne $memb1  ]; then
	echo ""
echo "Memory error : $mema1 -> $memb1";exit 1 
fi


echo " done"


printf " Check queue commands ............................................"

mema1=`dio87c -- memory`
if [ $? -ne 0 ]; then
if [ "$mema1" = "Unknown command 'memory'" ]; then
mema1=0
else
echo ""
echo "Error of the memory command";exit 1  
fi

fi

dio87c -- ta tg1 || exit 1 
dio87c -- ta tg2 || exit 1 

dio87c -- qa tg1 q1 
if [  $? -ne 0 ]; then
echo ""
echo "Can't create a new queue!";exit 1 
fi


dio87c -- qa tg1 q2 
if [  $? -ne 0 ]; then
echo ""
echo "Can't create a new queue!";exit 1 
fi


dio87c -- qa tg2 q3 
if [  $? -ne 0 ]; then
echo ""
echo "Can't create a new queue!";exit 1 
fi


dio87c -- qa tg2 q4 
if [  $? -ne 0 ]; then
echo ""
echo "Can't create a new queue!";exit 1 
fi



dio87c -- ql tg1 | grep "^batch$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue batch!";exit 1 
fi

dio87c -- ql tg1 | grep "^q1$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue q1!";exit 1 
fi

dio87c -- ql tg1 | grep "^q2$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue q2!";exit 1 
fi

res=`dio87c -- qc tg1`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get queue count!";exit 1 
fi

if [ $res -ne 3 ]; then
echo ""
echo "Target count is not 3!";exit 1 
fi

dio87c -- ql tg2 | grep "^batch$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue batch!";exit 1 
fi

dio87c -- ql tg2 | grep "^q3$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue q3!";exit 1 
fi

dio87c -- ql tg2 | grep "^q4$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue q4!";exit 1 
fi

res=`dio87c -- qc tg2`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get queue count!";exit 1 
fi

if [ $res -ne 3 ]; then
echo ""
echo "Target count is not 3!";exit 1 
fi


dio87c -- qa tg1 q1 > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can add a second queue with the same name!";exit 1 
fi

res=`dio87c -- qc tg1`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get queue count!";exit 1 
fi

if [ $res -ne 3 ]; then
echo ""
echo "Queue count is not 3!";exit 1 
fi


dio87c -- qsn tg1 q1 new_q1 
if [  $? -ne 0 ]; then
echo ""
echo "Can't rename the queue!";exit 1 
fi


dio87c -- ql tg1 | grep "^new_q1$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the renamed queue!";exit 1 
fi

dio87c -- qsn tg1 new_q1 q1 
if [  $? -ne 0 ]; then
echo ""
echo "Can't rename the queue!";exit 1 
fi


dio87c -- qsn tg1 q1 q2 > /dev/null 
if [ $? -eq 0 ]; then
Can rename a queue with a name which already exists!
fi

dio87c -- ql tg1 | grep "^q1$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue q1!";exit 1 
fi

dio87c -- ql tg1 | grep "^q2$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue q2!";exit 1 
fi


dio87c -- qsd tg1 q1 new_description 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change queue description!";exit 1 
fi


dio87c -- qi tg1 q1 -S_ | grep "^Description_new_description$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Queue description was not changed!";exit 1 
fi

dio87c -- qsd tg1 q1 "" 
if [  $? -ne 0 ]; then
echo ""
echo "Can't erase queue description!";exit 1 
fi


dio87c -- qi tg1 q1 -S_ | grep "^Description_$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Queue description was not changed!";exit 1 
fi


dio87c -- qso tg1 q1 false 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change the 'opened' property!";exit 1 
fi


dio87c -- qi tg1 q1 -S_ | grep "^Opened_false$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Queue 'opened' property was not changed!";exit 1 
fi

dio87c -- qso tg1 q1 true 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change the 'opened' property!";exit 1 
fi


dio87c -- qi tg1 q1 -S_ | grep "^Opened_true$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Queue 'opened' property was not changed!";exit 1 
fi


dio87c -- qsm tg1 q1 99 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change the 'max' property!";exit 1 
fi


dio87c -- qi tg1 q1 -S_ | grep "^Max_99$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Queue 'max' property was not changed!";exit 1 
fi

dio87c -- qsm tg1 q1 100 
if [  $? -ne 0 ]; then
echo ""
echo "Can't change the 'max' property!";exit 1 
fi


dio87c -- qi tg1 q1 -S_ | grep "^Max_100$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Queue 'max' property was not changed!";exit 1 
fi


dio87c -- qk tg1 q1 > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can delete a queue (q1)!";exit 1 
fi

res=`dio87c -- qc tg1`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get queue count!";exit 1 
fi

if [ $res -ne 2 ]; then
echo ""
echo "Queue count is not 2!";exit 1 
fi


dio87c -- qk tg1 q2 > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can delete a queue (q2)!";exit 1 
fi

res=`dio87c -- qc tg1`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get queue count!";exit 1 
fi

if [ $res -ne 1 ]; then
echo ""
echo "Queue count is not 1!";exit 1 
fi


dio87c -- tk tg1 || exit 1 
dio87c -- tk tg2 || exit 1 

mema2=`dio87c -- memory`
if [ $? -ne 0 ]; then
if [ "$mema2" = "Unknown command 'memory'" ]; then
mema2=0
else
echo ""
echo "Error of the memory command";exit 1  
fi

fi

dio87c -- ta tg1 || exit 1 
dio87c -- qa tg1 q1 || exit 1 
dio87c -- qa tg1 q2 || exit 1 
dio87c -- qa tg1 q3 || exit 1 
dio87c -- tk tg1 || exit 1 
memb2=`dio87c -- memory`
if [ $? -ne 0 ]; then
if [ "$memb2" = "Unknown command 'memory'" ]; then
memb2=0
else
echo ""
echo "Error of the memory command";exit 1  
fi

fi
if [  $mema2 -ne $memb2  ]; then
	echo ""
echo "Memory error : $mema2 -> $memb2";exit 1 
fi


dio87c -- ta tg1 || exit 1 
dio87c -- qa tg1 "abAZ09-" 
if [  $? -ne 0 ]; then
echo ""
echo "Can't create a queue with valid character!";exit 1 
fi


dio87c -- ql tg1 | grep "^abAZ09-$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue!";exit 1 
fi

dio87c -- qk tg1 "abAZ09-" || exit 1 
dio87c -- qa tg1 "queue@" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can add a queue with invalid character!";exit 1 
fi

dio87c -- ql tg1 | grep "^queue@$" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "The queue was created !";exit 1 
fi

dio87c -- qa tg1 "" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can add a queue with an empty name!";exit 1 
fi

dio87c -- tk tg1 || exit 1 

dio87c -- ta tg1 || exit 1 
dio87c -- qa tg1 q1 || exit 1 
dio87c -- qsn tg1 q1 "abAZ09-" 
if [  $? -ne 0 ]; then
echo ""
echo "Can't rename a queue with valid character!";exit 1 
fi


dio87c -- ql tg1 | grep "^abAZ09-$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the queue!";exit 1 
fi

dio87c -- qsn tg1 "abAZ09-" q1 || exit 1 
dio87c -- qsn tg1 q1 "queue@" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can rename a queue with invalid character!";exit 1 
fi

dio87c -- ql tg1 | grep "^queue@$" > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "The queue was created!";exit 1 
fi

dio87c -- tk tg1 || exit 1 


dio87c -- ql localhost | grep "^batch$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "Can't find the batch queue of localhost!";exit 1 
fi

res=`dio87c -- qc localhost`
if [ $? -ne 0 ]; then
echo ""
echo "Can't get queue count!";exit 1 
fi

if [ $res -ne 1 ]; then
echo ""
echo "Queue count of localhost is not 1!";exit 1 
fi

dio87c -- qk localhost batch > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can kill the batch queue of localhost!";exit 1 
fi

dio87c -- ql localhost | grep "^batch$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "The batch queue of localhost has been deleted!";exit 1 
fi

dio87c -- qsn localhost batch new_name > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "Can rename the batch queue of localhost!";exit 1 
fi

dio87c -- ql localhost | grep "^batch$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "The batch queue of localhost has been renamed!";exit 1 
fi




memb1=`dio87c -- memory`
if [ $? -ne 0 ]; then
if [ "$memb1" = "Unknown command 'memory'" ]; then
memb1=0
else
echo ""
echo "Error of the memory command";exit 1  
fi

fi
if [  $mema1 -ne $memb1  ]; then
	echo ""
echo "Memory error : $mema1 -> $memb1";exit 1 
fi


echo " done"


printf " Stop dio87d ....................................................."

pid=`ps -e | grep [d]io87d`
if [ $? -ne 0 ]; then
echo ""
echo "dio87d is not executing";exit 1 
fi
pid=`echo $pid | awk '{print $1}'`
kill -s TERM $pid
sleep 1 
ps -e | grep [d]io87d > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "dio87d is not stopped";exit 1 
fi

echo " done"
i=0
while ls "$DATAPATH" | grep "dio87d.pid" >/dev/null
do
	i=$((i+1))
	sleep 1
	if test $i -eq 10 
	then 
		echo "The PID file is not deleted"
		exit 1
	fi
done
rm -f "$DATAPATH"/*.conf || exit 1
rm -f "$DATAPATH"/*.data || exit 1
rmdir "$DATAPATH" || exit 1


