#! /bin/sh
#
#      Diogene87
#      Copyright (C) 2003,2004,2005,2006,2007 - Dominique Parisot
#
if [ "x$buildpath" = "x" ] ; then
	buildpath=`pwd`
fi
if [ "`uname`" = "Linux" ] ; then
	echo "Setting ulimit"
	ulimit -c unlimited
	ulimit -n 10
fi

dio87d_dir="$buildpath/../src/dio87d"
dio87c_dir="$buildpath/../src/dio87c"
dio87d_cmd="$dio87d_dir/dio87d"
dio87c_cmd="$dio87c_dir/dio87c"
PATH="$dio87d_dir:$dio87c_dir:$PATH"
export PATH
export DG87_USER="admin"
export DG87_PASSWORD=""
JOBPATH="$buildpath/$srcdir/jobs"
DATAPATH="$buildpath/data"
dayDate=`date +"%Y-%m-%d %H:%M:%S"`
# check data directory
if [ ! -d "$DATAPATH"  ]; then
# create directory
mkdir "$DATAPATH" || exit 1 
else
# remove previous data files
rm "$DATAPATH"/* -f >/dev/null 2>&1 
fi
# create 'dio87d' configuration file
cat > $DATAPATH/dio87d.conf << EOF
IPPORT=9993
PID_FILE=$DATAPATH/dio87d.pid
DATA_DIR=$DATAPATH
SAVE_TEMPO=300
LOG_LEVEL=NONE
EOF

# create 'dio87c' configuration file
cat > $DATAPATH/dio87c.conf << EOF
DG87_ADDRESS=localhost
DG87_IPPORT=9993
EOF
ps -e | grep [d]io87d > /dev/null 
if [ $? -eq 0 ]; then

echo "dio87d is already running";exit 1 
fi

echo "__________________________________________________________________"

echo "|"

echo "| tst07 (Check the property 'opened')"

echo "|"

printf " Start dio87d ...................................................."

# initialize previous database
rm DATAPATH/dio87d.data >/dev/null 2>&1
"$dio87d_cmd" -C "$DATAPATH/dio87d.conf" -I >/dev/null 2>&1
"$dio87d_cmd" -C "$DATAPATH/dio87d.conf" -d $DAEMON_OPTION
sleep 1
dio87c -- version >/dev/null 2>&1
if [  $? -ne 0 ]; then
echo ""
echo "Can't communicate with dio87d";exit 1 
fi


echo " done"

printf " Test the target open/close property  ............................"

mema1=`dio87c -- memory`
if [ $? -ne 0 ]; then
if [ "$mema1" = "Unknown command 'memory'" ]; then
mema1=0
else
echo ""
echo "Error of the memory command";exit 1  
fi

fi

res=`dio87c -- ti localhost`
if [ $? -ne 0 ]; then
echo ""
echo "The command 'ti localhost' returns an error";exit 1 
fi
echo "$res" | grep "^Opened:.true$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "ERROR: The command (ti localhost) does not return (Opened:true)" echo ""
echo "By default a target should be opened";exit 1 
fi

dio87c -- tso localhost false || exit 1 
res=`dio87c -- ti localhost`
if [ $? -ne 0 ]; then
echo ""
echo "The command 'ti localhost' returns an error";exit 1 
fi
echo "$res" | grep "^Opened:.false$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "ERROR: The command (ti localhost) does not return (Opened:false)" echo ""
echo "The target is not closed!";exit 1 
fi

dio87c -- tso localhost true || exit 1 
res=`dio87c -- ti localhost`
if [ $? -ne 0 ]; then
echo ""
echo "The command 'ti localhost' returns an error";exit 1 
fi
echo "$res" | grep "^Opened:.true$" > /dev/null 
if [ $? -ne 0 ]; then
echo ""
echo "ERROR: The command (ti localhost) does not return (Opened:true)" echo ""
echo "The target is not opened!";exit 1 
fi


memb1=`dio87c -- memory`
if [ $? -ne 0 ]; then
if [ "$memb1" = "Unknown command 'memory'" ]; then
memb1=0
else
echo ""
echo "Error of the memory command";exit 1  
fi

fi
if [  $mema1 -ne $memb1  ]; then
	echo ""
echo "Memory error : $mema1 -> $memb1";exit 1 
fi


echo " done"

dio87c -- tso localhost false || exit 1 
dio87c -- ra r1 || exit 1 
dio87c -- rta r1 t1 || exit 1 
dio87c -- rtoa r1 t1 add always || exit 1 
dio87c -- rja r1 t1 j1 || exit 1 
dio87c -- rjsp r1 t1 j1 "/bin/sleep" || exit 1 
dio87c -- rjsa r1 t1 j1 5 || exit 1 

dio87c -- rp r1 today d1 > /dev/null 
if [ $? -ne 0 ]; then
exit 1 
fi


sleep 2 
res=`dio87c -- xji d1 t1 j1`
if [ $? -ne 0 ]; then
echo "The command 'xji d1 t1 j1' returns an error";exit 1 
fi
echo "$res" | grep "^State:.wait_target$" > /dev/null 
if [ $? -ne 0 ]; then

echo "ERROR: The command (xji d1 t1 j1) does not return (State:wait_target)" 
echo "The state of j1 is not 'wait_target'!";exit 1 
fi

res=`dio87c -- xti d1 t1`
if [ $? -ne 0 ]; then
echo "The command 'xti d1 t1' returns an error";exit 1 
fi
echo "$res" | grep "^State:.running$" > /dev/null 
if [ $? -ne 0 ]; then

echo "ERROR: The command (xti d1 t1) does not return (State:running)" 
echo "The state of t1 is not 'running'!";exit 1 
fi


res=`dio87c -- qxjc localhost batch`
if [ $? -ne 0 ]; then
echo "The command 'qxjc localhost batch' returns an error";exit 1 
fi

echo "$res" | grep "^1$" > /dev/null 
if [ $? -ne 0 ]; then

echo "The number of running jobs in the queue is not 1!";exit 1 
fi

res=`dio87c -- qxjl -S_ localhost batch`
if [ $? -ne 0 ]; then
echo "The command 'qxjl -S_ localhost batch' returns an error";exit 1 
fi

echo "$res" | grep "^d1_t1_j1$" > /dev/null 
if [ $? -ne 0 ]; then

echo "Can't find the job j1 in the qxjl result";exit 1 
fi


dio87c -- tso localhost true || exit 1 
sleep 2 

res=`dio87c -- xji d1 t1 j1`
if [ $? -ne 0 ]; then
echo "The command 'xji d1 t1 j1' returns an error";exit 1 
fi
echo "$res" | grep "^State:.running$" > /dev/null 
if [ $? -ne 0 ]; then

echo "ERROR: The command (xji d1 t1 j1) does not return (State:running)" 
echo "The state of j1 is not 'running'!";exit 1 
fi

res=`dio87c -- xti d1 t1`
if [ $? -ne 0 ]; then
echo "The command 'xti d1 t1' returns an error";exit 1 
fi
echo "$res" | grep "^State:.running$" > /dev/null 
if [ $? -ne 0 ]; then

echo "ERROR: The command (xti d1 t1) does not return (State:running)" 
echo "The state of t1 is not 'running'!";exit 1 
fi


res=`dio87c -- qxjc localhost batch`
if [ $? -ne 0 ]; then
echo "The command 'qxjc localhost batch' returns an error";exit 1 
fi

echo "$res" | grep "^0$" > /dev/null 
if [ $? -eq 0 ]; then

echo "The number of running jobs in the queue is not 0!";exit 1 
fi


res=`dio87c -- qxjl -S_ localhost batch`
if [ $? -ne 0 ]; then
echo "The command 'qxjl -S_ localhost batch' returns an error";exit 1 
fi

echo "$res" | grep "^d1_t1_j1$" > /dev/null 
if [ $? -ne 0 ]; then

echo "The job j1 is not in the result of the qxjl result";exit 1 
fi


sleep 3 

res=`dio87c -- xji d1 t1 j1`
if [ $? -ne 0 ]; then
echo "The command 'xji d1 t1 j1' returns an error";exit 1 
fi
echo "$res" | grep "^State:.terminated$" > /dev/null 
if [ $? -ne 0 ]; then

echo "ERROR: The command (xji d1 t1 j1) does not return (State:terminated)" 
echo "The state of j1 is not 'terminated'!";exit 1 
fi

res=`dio87c -- xti d1 t1`
if [ $? -ne 0 ]; then
echo "The command 'xti d1 t1' returns an error";exit 1 
fi
echo "$res" | grep "^State:.terminated$" > /dev/null 
if [ $? -ne 0 ]; then

echo "ERROR: The command (xti d1 t1) does not return (State:terminated)" 
echo "The state of t1 is not 'terminated'!";exit 1 
fi


res=`dio87c -- qxjl -S_ localhost batch`
if [ $? -ne 0 ]; then
echo "The command 'qxjl -S_ localhost batch' returns an error";exit 1 
fi

echo "$res" | grep "^d1_t1_j1$" > /dev/null 
if [ $? -eq 0 ]; then

echo "The job j1 is in the result of the qxjl result";exit 1 
fi




dio87c -- rk r1 || exit 1 

printf " Stop dio87d ....................................................."

pid=`ps -e | grep [d]io87d`
if [ $? -ne 0 ]; then
echo ""
echo "dio87d is not executing";exit 1 
fi
pid=`echo $pid | awk '{print $1}'`
kill -s TERM $pid
sleep 1 
ps -e | grep [d]io87d > /dev/null 
if [ $? -eq 0 ]; then
echo ""
echo "dio87d is not stopped";exit 1 
fi

echo " done"

i=0
while ls "$DATAPATH" | grep "dio87d.pid" >/dev/null
do
	i=$((i+1))
	sleep 1
	if test $i -eq 10 
	then 
		echo "The PID file is not deleted"
		exit 1
	fi
done
rm -f "$DATAPATH"/*.conf || exit 1
rm -f "$DATAPATH"/*.data || exit 1
rmdir "$DATAPATH" || exit 1



