#!/bin/sh
#
# file tst35.sh 
# (test rtd and rjd commands)
#
#      Diogene87
#	Copyright (C) 2003,2004,2005,2006,2007 - Dominique Parisot
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this software; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA 02111-1307 USA
#


if [ "$srcdir" = "" ]; then srcdir="."; fi
. $srcdir/functions.sh
checkNoDaemon

echo "test rtd and rjd commands"

startDio87d || exit 1

echo "Verify 'rtd' command"

echo " check command call with bad arguments"
dio87c -- rtd a b >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with 2 arguments"; exit 1
fi
dio87c -- rtd a b c d e  >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with 5 arguments"; exit 1
fi
dio87c -- rtd rx tx ty >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with incorrect referential name"; exit 1
fi
dio87c -- ra r1 || exit 1
dio87c -- rtd r1 tx ty >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with incorrect task name"; exit 1
fi
dio87c -- rta r1 t1 || exit 1
dio87c -- rtd r1 t1 rx ty >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with incorrect destination referential name"; exit 1
fi
dio87c rk r1 || exit 1



dio87c -- va var1 || exit 1
dio87c -- va var2 || exit 1

memd1=`dio87c -- memory` || exit 1
	
# first task
dio87c -- ra r1 || exit 1
dio87c -- rta r1 t1 || exit 1
dio87c -- rtsd r1 t1 "first task" || exit 1
dio87c -- rtswad r1 t1 false || exit 1
dio87c -- rtsoec r1 t1 true || exit 1
dio87c -- rtse r1 t1 true || exit 1
dio87c -- rtsc r1 t1 33 44 begin || exit 1
dio87c -- rtsl r1 t1 none || exit 1
dio87c -- rtst r1 t1 none || exit 1

# second task
dio87c -- rta r1 t2 || exit 1
dio87c -- rtsd r1 t2 "second task" || exit 1
dio87c -- rtswad r1 t2 true || exit 1
dio87c -- rtsoec r1 t2 false || exit 1
dio87c -- rtse r1 t2 false || exit 1
dio87c -- rtsc r1 t2 55 66 end || exit 1
dio87c -- rtsl r1 t2 var1 lock || exit 1

# first job
dio87c -- rja r1 t1 j1 || exit 1
dio87c -- rjsd r1 t1 j1 "first job" || exit 1
dio87c -- rjsp r1 t1 j1 "/bin/ls" || exit 1
dio87c -- rjsa r1 t1 j1 "arg" || exit 1
dio87c -- rjst r1 t1 j1 30 40 || exit 1
dio87c -- rjswad r1 t1 j1 true || exit 1
dio87c -- rjsoec r1 t1 j1 false || exit 1

# second job
dio87c -- rja r1 t1 j2 || exit 1
dio87c -- rjswad r1 t1 j2 false || exit 1
dio87c -- rjsoec r1 t1 j2 true || exit 1

# third  job
dio87c -- rja r1 t1 j3 || exit 1

# job dependencies
dio87c -- rjda r1 t1 j1 j2 always || exit 1
dio87c -- rjda r1 t1 j1 j3 onSuccess || exit 1
dio87c -- rjda r1 t1 j2 j3 onError || exit 1

# task conditions
dio87c -- rtca r1 t1 hmin "08:00" 0 || exit 1
dio87c -- rtca r1 t1 hmax "09:00" 0 || exit 1
dio87c -- rtca r1 t1 hlate "11:00" 0 || exit 1
dio87c -- rtca r1 t1 manual "OK" || exit 1
dio87c -- rtca r1 t1 file "/tmp/fictop" || exit 1
dio87c -- rtca r1 t1 if_equal var1 value1 || exit 1
dio87c -- rtca r1 t1 if_not_equal var2 value2 || exit 1
dio87c -- rtca r1 t2 hmin "06:00" 1 || exit 1
dio87c -- rtca r1 t2 hmax "07:00" 1 || exit 1
dio87c -- rtca r1 t2 hlate "08:00" 1 || exit 1

# task operations
dio87c -- rtoa r1 t1 add day "03-03"|| exit 1
dio87c -- rtoa r1 t1 add_from day "04-03"|| exit 1
dio87c -- rtoa r1 t1 add_until day "05-03"|| exit 1
dio87c -- rtoa r1 t1 remove day "06-03"|| exit 1
dio87c -- rtoa r1 t1 remove_from day "07-03"|| exit 1
dio87c -- rtoa r1 t1 remove_until day "08-03"|| exit 1
dio87c -- rtoa r1 t1 shift_after day "09-03"|| exit 1
dio87c -- rtoa r1 t1 shift_before day "10-03"|| exit 1

dio87c -- rtoa r1 t2 add always || exit 1
dio87c -- rtoa r1 t2 add day_of_week 4 || exit 1
dio87c -- rtoa r1 t2 add day_of_month 5 || exit 1
dio87c -- rtoa r1 t2 add day_of_year 6 || exit 1
dio87c -- rtoa r1 t2 add week_of_month 1 || exit 1
dio87c -- rtoa r1 t2 add week_of_year 2 || exit 1
dio87c -- rtoa r1 t2 add month_of_year 3 || exit 1
dio87c -- rtoa r1 t2 add date "2004-03-02" || exit 1


# copy tasks
memd3=`dio87c -- memory` || exit 1
dio87c -- rtd r1 t1 c1 || exit 1
dio87c -- rtd r1 t2 c2 || exit 1

echo " check tasks"
# verify first task 
if [ "`dio87c -- rti r1 c1 -S! | grep \"Description!first task\" | wc -l`" -ne 1 ]; then
	echo "Description of c1 is not set"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S! | grep \"Wait All Dependencies!false\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Wait All Dependencies' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S! | grep \"On Error Continue!true\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'On Error Continue' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S! | grep \"Target!none\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Target' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S! | grep \"Queue!none\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Queue' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S_ | grep \"Enabled_true\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Enabled' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S_ | grep \"Iterations_33\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Iterations' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S_ | grep \"Interval_44\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Interval' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S_ | grep \"From_begin\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'From' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S_ | grep \"Lock Variable_none\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Lock variable' of task 'c1'"; exit 1
fi
if [ "`dio87c -- rti r1 c1 -S_ | grep \"Lock Action_none\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Lock action' of task 'c1'"; exit 1
fi

# verify second task 
if [ "`dio87c -- rti r1 c2 -S! | grep \"Description!second task\" | wc -l`" -ne 1 ]; then
	echo "Description of c2 is not set"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S! | grep \"Wait All Dependencies!true\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Wait All Dependencies' of task 'c2'"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S! | grep \"On Error Continue!false\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'On Error Continue' of task 'c2'"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S! | grep \"Target!localhost\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Target' of task 'c2'"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S! | grep \"Queue!batch\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Queue' of task 'c2'"; exit 1
fi

if [ "`dio87c -- rti r1 c2 -S_ | grep \"Enabled_false\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Enabled' of task 'c2'"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S_ | grep \"Iterations_55\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Iterations' of task 'c2'"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S_ | grep \"Interval_66\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Interval' of task 'c2'"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S_ | grep \"From_end\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'From' of task 'c2'"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S_ | grep \"Lock Variable_var1\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Lock variable' of task 'c2'"; exit 1
fi
if [ "`dio87c -- rti r1 c2 -S_ | grep \"Lock Action_lock\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Lock action' of task 'c2'"; exit 1
fi
if [ "`dio87c -- vi var1 -S_ | grep \"Linked Ref Tasks_2\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Linked Tasks' of variable 'var1'"; exit 1
fi

echo " check jobs"
#verifiy first job
if [ "`dio87c -- rji r1 c1 j1 -S! | grep \"Description!first job\" | wc -l`" -ne 1 ]; then
	echo "Description of j1 is not set"; exit 1
fi
if [ "`dio87c -- rji r1 c1 j1 -S! | grep \"Path!/bin/ls\" | wc -l`" -ne 1 ]; then
	echo "Path of j1 is not set"; exit 1
fi
if [ "`dio87c -- rji r1 c1 j1 -S! | grep \"Argument!arg\" | wc -l`" -ne 1 ]; then
	echo "Argument of j1 is not set"; exit 1
fi
if [ "`dio87c -- rji r1 c1 j1 -S! | grep \"Start Tempo!30\" | wc -l`" -ne 1 ]; then
	echo "Start tempo of j1 is not set"; exit 1
fi
if [ "`dio87c -- rji r1 c1 j1 -S! | grep \"End Tempo!40\" | wc -l`" -ne 1 ]; then
	echo "End tempo of j1 is not set"; exit 1
fi
if [ "`dio87c -- rji r1 c1 j1 -S! | grep \"Wait All Dependencies!true\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Wait All Dependencies' of job 'j1'"; exit 1
fi
if [ "`dio87c -- rji r1 c1 j1 -S! | grep \"On Error Continue!false\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'On Error Continue' of job 'j1'"; exit 1
fi

# verify second job 
if [ "`dio87c -- rji r1 c1 j2 -S! | grep \"Wait All Dependencies!false\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'Wait All Dependencies' of job 'j2'"; exit 1
fi
if [ "`dio87c -- rji r1 c1 j2 -S! | grep \"On Error Continue!true\" | wc -l`" -ne 1 ]; then
	echo "Incorrect value for 'On Error Continue' of job 'j2'"; exit 1
fi

# verify job dependencies
if [ "`dio87c -- rjdl r1 c1 -tS! | grep \"j1!j2!always\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'always' job dependence"; exit 1
fi
if [ "`dio87c -- rjdl r1 c1 -tS! | grep \"j1!j3!onsuccess\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'onSuccess' job dependence"; exit 1
fi
if [ "`dio87c -- rjdl r1 c1 -tS! | grep \"j2!j3!onerror\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'onError' job dependence"; exit 1
fi

echo " check conditions"
# verify task conditions
if [ "`dio87c -- rtcl r1 c1 -S! | grep \"hmin!08:00!+0\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'hmin' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c1 -S! | grep \"hmax!09:00!+0\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'hmax' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c1 -S! | grep \"hlate!11:00!+0\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'hlate' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c1 -S! | grep \"manual!OK\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'manual' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c1 -S! | grep \"file!/tmp/fictop\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'file' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c1 -S! | grep \"if_equal!var1!value1\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'if_equal' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c1 -S! | grep \"if_not_equal!var2!value2\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'if_not_equal' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c2 -S! | grep \"hmin!06:00!+1\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'hmin' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c2 -S! | grep \"hmax!07:00!+1\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'hmax' task condition"; exit 1
fi
if [ "`dio87c -- rtcl r1 c2 -S! | grep \"hlate!08:00!+1\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'hlate' task condition"; exit 1
fi

echo " check operations"
# verify task operations of task 1
if [ "`dio87c -- rtol r1 c1 -S! | grep \"add!day!03-03\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add day' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c1 -S! | grep \"add_from!day!04-03\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add_from day' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c1 -S! | grep \"add_until!day!05-03\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add_until day' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c1 -S! | grep \"remove!day!06-03\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'remove day' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c1 -S! | grep \"remove_from!day!07-03\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'remove_from day' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c1 -S! | grep \"remove_until!day!08-03\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'remove_until day' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c1 -S! | grep \"shift_after!day!09-03\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'shift_after day' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c1 -S! | grep \"shift_before!day!10-03\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'shift_before day' task operation"; exit 1
fi

# verify task operations of task 2
if [ "`dio87c -- rtol r1 c2 -S! | grep \"add!always\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add always' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c2 -S! | grep \"add!day_of_week!4\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add day_of_week' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c2 -S! | grep \"add!day_of_month!5\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add day_of_month' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c2 -S! | grep \"add!day_of_year!6\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add day_of_year' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c2 -S! | grep \"add!week_of_month!1\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add week_of_month' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c2 -S! | grep \"add!week_of_year!2\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add week_of_year' task operation"; exit 1
fi
if [ "`dio87c -- rtol r1 c2 -S! | grep \"add!month_of_year!3\" | wc -l`" -ne 1 ]; then
	echo "Can't find 'add month_of_year' task operation"; exit 1
fi

# delete copies of tasks
dio87c -- rtk r1 c1 || exit 1
dio87c -- rtk r1 c2 || exit 1

# verify memory
memd4=`dio87c -- memory` || exit 1
if [ $memd3 != $memd4 ] ; then
	echo "dio87d : memory error $memd3 -> $memd4 after deleting copies of tasks"; exit 1
fi

# kill referential
dio87c -- rk r1 || exit 1

# verify memory
memd2=`dio87c -- memory` || exit 1
if [ $memd1 != $memd2 ] ; then
	echo "dio87d : memory error $memd1 -> $memd2 after deleting referential"; exit 1
fi


echo "Verify the 'rjd' command"

memd1=`dio87c -- memory` || exit 1

echo " check command call with bad arguments"
dio87c -- rjd a b c >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with 3 arguments"; exit 1
fi
dio87c -- rjd a b c d e f g >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with 6 arguments"; exit 1
fi
dio87c -- rjd rx tx jx jy  >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with incorrect referential name"; exit 1
fi
dio87c -- ra r1 || exit 1
dio87c -- rjd r1 tx jx jy  >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with incorrect task name"; exit 1
fi
dio87c -- rta r1 t1 || exit 1
dio87c -- rjd r1 t1 jx jy >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with incorrect job name"; exit 1
fi
dio87c -- rja r1 t1 j1 || exit 1
dio87c -- rjd r1 t1 j1 rx jy >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with incorrect destination referential name"; exit 1
fi
dio87c -- ra r2 || exit 1
dio87c -- rjd r1 t1 j1 r2 tx jy >/dev/null
if [ $? -eq 0 ] ; then
	echo "no error with incorrect destination target name"; exit 1
fi
dio87c rk r1 || exit 1
dio87c rk r2 || exit 1


echo " duplicate a job in the same task"

dio87c -- ra r1 || exit 1
dio87c -- rta r1 t1 || exit 1
dio87c -- rja r1 t1 j1 "a job" || exit 1
dio87c -- rjsp r1 t1 j1 "/bin/ls" || exit 1
dio87c -- rjsa r1 t1 j1 "/tmp" || exit 1
dio87c -- rjst r1 t1 j1 48 49 || exit 1
dio87c -- rjswad r1 t1 j1 false || exit 1
dio87c -- rjsoec r1 t1 j1 true || exit 1

if [ "`dio87c rjc -- r1 t1`" -ne 1 ] ; then
	echo "Job count is not one" ; exit 1
fi

dio87c -- rjd r1 t1 j1 j1bis 
if [ $? -ne 0 ] ; then
	echo "Can't duplicate the job !"; exit 1
fi

if [ "`dio87c rjc -- r1 t1`" -ne 2 ] ; then
	echo "Job count is not two" ; exit 1
fi

dio87c -- rji -S_ r1 t1 j1bis | grep "Description_a job" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Description is not set"; exit 1
fi
dio87c -- rji -S_ r1 t1 j1bis | grep "Path_/bin/ls" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Path is not set"; exit 1
fi
dio87c -- rji -S_ r1 t1 j1bis | grep "Argument_/tmp" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Argument is not set"; exit 1
fi
dio87c -- rji -S_ r1 t1 j1bis | grep "Start Tempo_48" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Start tempo is not set"; exit 1
fi
dio87c -- rji -S_ r1 t1 j1bis | grep "End Tempo_49" >/dev/null
if [ $? -ne 0 ] ; then
	echo "End tempo is not set"; exit 1
fi
dio87c -- rji -S_ r1 t1 j1bis | grep "Wait All Dependencies_false" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Wait All Dependencies is not set (1)"; exit 1
fi
dio87c -- rji -S_ r1 t1 j1bis | grep "On Error Continue_true" >/dev/null
if [ $? -ne 0 ] ; then
	echo "On Error Continue is not set (1)"; exit 1
fi

dio87c -- rjswad r1 t1 j1 true || exit 1
dio87c -- rjsoec r1 t1 j1 false || exit 1

dio87c -- rjd r1 t1 j1 j1ter 
if [ $? -ne 0 ] ; then
	echo "Can't duplicate the job !"; exit 1
fi

if [ "`dio87c rjc -- r1 t1`" -ne 3 ] ; then
	echo "Job count is not two" ; exit 1
fi

dio87c -- rji -S_ r1 t1 j1ter | grep "Wait All Dependencies_true" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Wait All Dependencies is not set (2)"; exit 1
fi
dio87c -- rji -S_ r1 t1 j1ter | grep "On Error Continue_false" >/dev/null
if [ $? -ne 0 ] ; then
	echo "On Error Continue is not set (2)"; exit 1
fi


dio87c -- rk r1 || exit 1


echo " duplicate a job in another task"

dio87c -- ra r1 || exit 1
dio87c -- rta r1 t1 || exit 1
dio87c -- rta r1 t2 || exit 1
dio87c -- rja r1 t1 j1 "a job" || exit 1
dio87c -- rjsp r1 t1 j1 "/bin/ls" || exit 1
dio87c -- rjsa r1 t1 j1 "/tmp" || exit 1
dio87c -- rjst r1 t1 j1 48 49 || exit 1
dio87c -- rjswad r1 t1 j1 false || exit 1
dio87c -- rjsoec r1 t1 j1 true || exit 1

if [ "`dio87c rjc -- r1 t1`" -ne 1 ] ; then
	echo "Job count is not one" ; exit 1
fi

dio87c -- rjd r1 t1 j1 t2 j1bis 
if [ $? -ne 0 ] ; then
	echo "Can't duplicate the job !"; exit 1
fi

if [ "`dio87c rjc -- r1 t1`" -ne 1 ] ; then
	echo "Job count is not one in t1" ; exit 1
fi
if [ "`dio87c rjc -- r1 t2`" -ne 1 ] ; then
	echo "Job count is not one in t2" ; exit 1
fi

dio87c -- rji -S_ r1 t2 j1bis | grep "Description_a job" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Description is not set"; exit 1
fi
dio87c -- rji -S_ r1 t2 j1bis | grep "Path_/bin/ls" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Path is not set"; exit 1
fi
dio87c -- rji -S_ r1 t2 j1bis | grep "Argument_/tmp" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Argument is not set"; exit 1
fi
dio87c -- rji -S_ r1 t2 j1bis | grep "Start Tempo_48" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Start tempo is not set"; exit 1
fi
dio87c -- rji -S_ r1 t2 j1bis | grep "End Tempo_49" >/dev/null
if [ $? -ne 0 ] ; then
	echo "End tempo is not set"; exit 1
fi
dio87c -- rji -S_ r1 t2 j1bis | grep "Wait All Dependencies_false" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Wait All Dependencies is not set (1)"; exit 1
fi
dio87c -- rji -S_ r1 t2 j1bis | grep "On Error Continue_true" >/dev/null
if [ $? -ne 0 ] ; then
	echo "On Error Continue is not set (1)"; exit 1
fi

dio87c -- rjswad r1 t1 j1 true || exit 1
dio87c -- rjsoec r1 t1 j1 false || exit 1

dio87c -- rjd r1 t1 j1 t2 j1ter 
if [ $? -ne 0 ] ; then
	echo "Can't duplicate the job !"; exit 1
fi

if [ "`dio87c rjc -- r1 t1`" -ne 1 ] ; then
	echo "Job count is not two in t1" ; exit 1
fi
if [ "`dio87c rjc -- r1 t2`" -ne 2 ] ; then
	echo "Job count is not two in t2" ; exit 1
fi

dio87c -- rji -S_ r1 t2 j1ter | grep "Wait All Dependencies_true" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Wait All Dependencies is not set (2)"; exit 1
fi
dio87c -- rji -S_ r1 t2 j1ter | grep "On Error Continue_false" >/dev/null
if [ $? -ne 0 ] ; then
	echo "On Error Continue is not set (2)"; exit 1
fi

dio87c -- rk r1 || exit 1


echo " duplicate a job in another referential"

dio87c -- ra r1 || exit 1
dio87c -- ra r2 || exit 1
dio87c -- rta r1 t1 || exit 1
dio87c -- rta r2 t2 || exit 1
dio87c -- rja r1 t1 j1 "a job" || exit 1
dio87c -- rjsp r1 t1 j1 "/bin/ls" || exit 1
dio87c -- rjsa r1 t1 j1 "/tmp" || exit 1
dio87c -- rjst r1 t1 j1 48 49 || exit 1
dio87c -- rjswad r1 t1 j1 false || exit 1
dio87c -- rjsoec r1 t1 j1 true || exit 1

if [ "`dio87c rjc -- r1 t1`" -ne 1 ] ; then
	echo "Job count is not one" ; exit 1
fi

dio87c -- rjd r1 t1 j1 r2 t2 j1bis 
if [ $? -ne 0 ] ; then
	echo "Can't duplicate the job !"; exit 1
fi

if [ "`dio87c rjc -- r1 t1`" -ne 1 ] ; then
	echo "Job count is not one in r1" ; exit 1
fi
if [ "`dio87c rjc -- r2 t2`" -ne 1 ] ; then
	echo "Job count is not one in r2" ; exit 1
fi

dio87c -- rji -S_ r2 t2 j1bis | grep "Description_a job" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Description is not set"; exit 1
fi
dio87c -- rji -S_ r2 t2 j1bis | grep "Path_/bin/ls" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Path is not set"; exit 1
fi
dio87c -- rji -S_ r2 t2 j1bis | grep "Argument_/tmp" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Argument is not set"; exit 1
fi
dio87c -- rji -S_ r2 t2 j1bis | grep "Start Tempo_48" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Start tempo is not set"; exit 1
fi
dio87c -- rji -S_ r2 t2 j1bis | grep "End Tempo_49" >/dev/null
if [ $? -ne 0 ] ; then
	echo "End tempo is not set"; exit 1
fi
dio87c -- rji -S_ r2 t2 j1bis | grep "Wait All Dependencies_false" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Wait All Dependencies is not set (1)"; exit 1
fi
dio87c -- rji -S_ r2 t2 j1bis | grep "On Error Continue_true" >/dev/null
if [ $? -ne 0 ] ; then
	echo "On Error Continue is not set (1)"; exit 1
fi

dio87c -- rjswad r1 t1 j1 true || exit 1
dio87c -- rjsoec r1 t1 j1 false || exit 1

dio87c -- rjd r1 t1 j1 r2 t2 j1ter 
if [ $? -ne 0 ] ; then
	echo "Can't duplicate the job !"; exit 1
fi

if [ "`dio87c rjc -- r1 t1`" -ne 1 ] ; then
	echo "Job count is not two in r1" ; exit 1
fi
if [ "`dio87c rjc -- r2 t2`" -ne 2 ] ; then
	echo "Job count is not two in r2" ; exit 1
fi

dio87c -- rji -S_ r2 t2 j1ter | grep "Wait All Dependencies_true" >/dev/null
if [ $? -ne 0 ] ; then
	echo "Wait All Dependencies is not set (2)"; exit 1
fi
dio87c -- rji -S_ r2 t2 j1ter | grep "On Error Continue_false" >/dev/null
if [ $? -ne 0 ] ; then
	echo "On Error Continue is not set (2)"; exit 1
fi

dio87c -- rk r2 || exit 1
dio87c -- rk r1 || exit 1

# verify memory
memd2=`dio87c -- memory` || exit 1
if [ $memd1 != $memd2 ] ; then
	echo "dio87d : memory error $memd1 -> $memd2 after deleting referential"; exit 1
fi

stopDio87d || exit 1

exit 0
