#!/bin/sh

CURDIR="`pwd`"
SPECFILE="$CURDIR/tmp/SPECS/diogene87.spec"
SPECFILEIN="$CURDIR/diogene87.spec.in"
RPMDIR="$CURDIR/tmp"

if [ ! -f $SPECFILEIN ]; then
	echo "Can't find '$SPECFILEIN' !"; exit 1
fi

if [ "$#" -ne 1 ] ; then
	echo "usage : ./makerpm [build|clean]"; exit 1
fi

action=$1
if [ $action != "clean" -a $action != "build" ] ; then
	echo "usage : ./buildpackage [clean|build]"; exit 1
fi


if [ "$action" == clean ] ; then
	echo "clean"
	if [ -d $RPMDIR ] ; then
		echo "remove $RPMDIR"
		rm -rf $RPMDIR
	fi
elif [ "$action" == build ] ; then

	if [ -d $RPMDIR ] ; then
		rm -rf $RPMDIR || exit 1
		mkdir $RPMDIR || exit 1
	fi

	# create tmp directories
	for rep in SPECS BUILD RPMS SRPMS INSTALL
	do
		if [ ! -f $RPMDIR/$rep ] ; then
			mkdir -p $RPMDIR/$rep || exit 1
		fi
	done
	# create SOURCES directories 
	test -h $RPMDIR/SOURCES && rm $RPMDIR/SOURCES 
	ln -s $CURDIR/.. $RPMDIR/SOURCES

	# extract version from configure.ac
	if [ ! -f ../configure.ac ] ; then
		echo "Can't find configure.ac !"; exit 1
	fi
	VERSION=`sed -ne "s/AC_INIT(.*,\[\(.*\)\],.*)/\1/p" ../configure.ac`

	# check rpmbuild program
	rpmbuild --version > /dev/null 2>&1
	if [ $? -ne 0 ] ; then
		echo "Can't find 'rpmbuild' !"; exit 1
	fi

	# check fakeroot program
	fakeroot --version >/dev/null 2>&1
	if [ $? -ne 0 ] ; then
		echo "Can't find 'fakeroot' !"; exit 1
	fi

	# check spec.in file
	if [ ! -f "$SPECFILEIN" ] ; then
		echo "Can't find $SPECFILEIN !" ; exit 1
	fi
	# clean previous Makefile
	if [ -f ../Makefile ] ; then
		(cd .. && make distclean)
	fi

	# create spec file from spec.in file
	sed -e "s!DG87_RPMDIR!$RPMDIR!g;" \
	    -e "s!DG87_VERSION!$VERSION!g;" \
		$SPECFILEIN > $SPECFILE	

	if [ ! -f "$SPECFILE" ] ; then
		echo "Can't find $SPECFILE !" ; exit 1
	fi

	echo "Building rpm packages ..."
	rpmbuild -bb $SPECFILE 
	if [ $? -ne 0 ] ; then
		echo "rpmbuild returns an error !"; exit 1
	else
		echo "RPM files :"
		find . -name "*.rpm"
	fi

fi
